Method: Comable::InstallGenerator#insert_routes

Defined in:
lib/generators/comable/install/install_generator.rb

#insert_routesObject



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/generators/comable/install/install_generator.rb', line 87

def insert_routes
  insert_into_file File.join('config', 'routes.rb'), after: "Rails.application.routes.draw do\n" do
    <<-ROUTES
  # This line mounts Comable's routes at the root of your application.
  # This means, any requests to URLs such as /products, will go to Comable::ProductsController.
  # If you would like to change where this engine is mounted, simply change the :at option to something different.
  #
  # We ask that you don't use the :as option here, as Comable relies on it being the default of "comable"
  mount Comable::Core::Engine, at: '/'
    ROUTES
  end

  message_for_insert_routes unless options[:quiet]
end